@@ -1,11 +1,12 @@
 class TerminalStyle:
     """
-    font styles for printing to terminal
+    Font styles for printing to terminal
     """
     RED = "\u001b[31m"
     GREEN = "\u001b[32m"
-    BLUE = "\u001b[34m"
+    BLUE = "\u001b[38;5;39m"
     YELLOW = "\u001b[38;5;11m"
+    ORANGE = "\u001b[38;5;208m"
     BOLD = "\u001b[1m"
     UNDERLINE = "\u001b[7m"
     RESET = "\033[0m"
